<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Alles wissen</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Invouwen</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Meer</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>Er zijn geen meldingen</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Meldingencentrum</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Alles wissen</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Invouwen</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Meer</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Losmaken</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Vastmaken</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Meldingsinstellingen</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation>Alles wissen</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Zojuist</translation>
    </message>
</context>
</TS>